****************
Acknowledgements
****************

Dune-MMesh has been developed by Samuel Burbulla during his PhD supervised by Christian Rohde at IANS at the University of Stuttgart.
Funded by the Deutsche Forschungsgemeinschaft (DFG, German Research Foundation) -- Project Number 327154368 -- SFB 1313.

We gratefully thank Andreas Dedner for all his support in particular in providing the Python bindings.
Thanks to all contributors that improved Dune-MMesh via the GitLab repository, especially Timo Koch.
